==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/89/8920e8a5b295408314ea036a9ec3b5de.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/paprika/assets/paprikas.jpg */
class __TwigTemplate_5049f6692acbe41a514e823d702136eb extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "\000JFIF\000\000`\000`\000\000\000hExif\000\000MM\000*\000\000\000\000\000\000\000\000\000\000\000>\000\000\000\000\000\000\000F(\000\000\000\000\000\000\0001\000\000\000\000\000\000\000N\000\000\000\000\000\000\000`\000\000\000\000\000\000`\000\000\000paint.net 4.2.15\000\000\000C\000\t\t\t





\t


\000C


















































\000\000!\000\000\000\000\000\000\000\000\000\000\000\000\t
\000\000\000\000}\000!1AQa\"q2#BR\$3br\t
%&'()*456789:CDEFGHIJSTUVWXYZcdefghijstuvwxyz\000\000\000\000\000\000\000\000\t
\000\000\000w\000!1AQaq\"2B\t#3Rbr
\$4%&'()*56789:CDEFGHIJSTUVWXYZcdefghijstuvwxyz\000\000\000?\000\000K\th
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(N=(\${J

(\000
(\000
(\000}(\000(\000(\000(\000(\000ct}}('w\000q@q@~x\000PG>\000Qրh(\000(J(\000Ҋ\000(\000(\000(\000(\000\t\000h7Nirs@AIށzR,zP!I4dB.dP=}h\000't0@\\\\rh~P0
(\000
(\000
(\0009\0009t@\000sF}(\000&}(9G^G~ZC
( hBt(?\000\000aizC_fq֨K@P]_\\46ֵ(ma_\$dxc]Wku2yqgxx\$9,\"1StRHE[:+9\000(\000ӹ E\000Q(Px\t9&@}M!(8'Es֨H\tj2I(.JP^KA~վ6.5Ե戲+{{}:U+I36dy_-i|-Y\\ڽ-\"SQu'&#\000G8w5վ\0006p\t8_<Lqy]Ƣ6.І;-pت9=fշI_~>@Bik>0(\000N(\000zQ@8\000 }(g>MAl@Sҏt'\0007Nր
P4x_kj=񦟥wrO5ˌapyVMF+V۰64\000~Ǘ|d˶ՔY?cmGxG^l`*N0!*8r˿ȊuֿviQ_LhyoWG迳%ImnLzMO0_s|GOxĨ&W\$fU%a\\vA+\t{4俿R7\000uRlBZ&%vn|ϻ~~>dVdl\\Q^_#-_YIR~m\000xDUIu
+p
(\000u\000&qր\"sPH7E'\000pґ4\000qPFy4MPEO\000x&34QeF\"s^g
/4Km'!U;-v[л\000? kx(b^}!dktv98XsM8|Dm\000ֻ>|,t{+{}?q~3,\000=ku\000○9u7㾛ٞXno(Vv\000?;@Oq[Fۦg'o?
lV)M\000u{g|1֩D\\Ix`ګm3\000\\|fu^(<k-ŕh%\$zG|vy9laq7.DݥlB2ю1{=\000~_ҼQ%oqxOCGqڱ+Qb\\C`yEskͰ8<yYZ`7Թ#)ҩVvݒoƟzW_SyesGğzc)q\000x_/q[<峸b<\"o*縕?iU܂\000TcStR*mtJͯ+h(\000(\000(oI5F8-i*Ơd'\000^\000J\000b{]xfmŬG\$1JARF]~5y<?[ڲi>U{Fq1<&j
Nɾ\000þGo\000oEu0ʪk\000V?íA7F閩&pat8֞#Y^OѦXƾ
後\000zk{zXjÚ~?Ӧ_Zcdw:*\000y
־+|0M6DXcsDڹqX&ɔ[<\000ğbjy\$_ek!1\tXe)Du
Jn6nrO_^,^_q\000q9/+53\\jp\"\000\\K_\000
Qն0M&\000Q\\\000평\000t_4I,33e2??̼Cn'RWKR^Wu3Ek5~ՏWD~
~#_Ǘ(dVЃ|r3}@~֟ƕIon-cgE#s+3 @q.sng{\000js[sstyo3\000@yh^31-V5CjTg>b?qcQ]P\$gyvq1n}ktAFniu;';v
X[^\000%럛eۃ\000bNH|Ac\$M갷@z
cl+
NӺMk\\ҵ\000?੟>
|\000hWr[ƭxSJ(ptӄ\000I]Ao3HY[)8fPJ#FM¿83NmC'RPN{쭦׿>3.>Y7WKo{uvm\000'_[|:wt uFm
Dnk{xm-㵶R8,hT~}.+3jμc.Oj=ܴދzp
(\000p>
i3X7uKn6vHN=kGuO
uVlI,Y8\$6A_~;`qZ꒼b)Kރ5+S*onFeh^(|te3Fs?ˊǾof]W!Z<&CͰs[VKc=Jrw}n{_w=SU߉~]2ׁuh\000BzgxPǠrzO},^*feĒhwvRRm?O+<;ݥNV[\0004ϥAJ*3,[R\000-('[fKonH<;615[G\000xsB/|Kflح1V8c=sἇ;>J޷ۭΟ<tZ\\Vڔ:߫%য়y,> |?-Y<ż3p6}8<+(Mÿ՝ջI|Gy-!9We(ӕH)OYNsuȿbZJ4ͷg}5]\000;??;i#0?G
a6
'o*O߃z<9\\h0K7)zX^\\q):F6\000ZkPsHub.co._M8,^MKݎ0:W>6-xUQMNI%9Ij:~35s;(DWO\\}IEii
f=1
O-[_/o)
z߽{X\\KxZTsڦuxv͑sB1o=Wᰴi[^]Hr|޻~(G\"8VL|בXgR%͢kJ/<_yEִ ocŇ̎M@}{ֿcw\000u[\000[KD\$u/\$wl\000fh䵳ojӕ(.^I\\IQF_6O>'[\000\000
ªoL\0009A6KaաN*+Vmr4yPE\000P0{K4\000P\t?z?{7y?s,v> V}U+c|rco;<[Éx~_-IũAs%~먧Nzr?I^hT\000c5
|Nmգ+~J:\000u
nu&{nNb2Dx8N
E_ѭOQYӒ?=S\000<4=ڹu(\\K|]{tN5b^ \$eZ컸!h2WB
rEu[\0003n5Y5.#v<VrxHҌm)N=/][.6mlu{iwgѹ(.̦ƔkrI\$zu)ɢOp!1Ȳ;VuWo*X<\000/JzB^ZkEvb{mU
τYй\000tq|9669dnvl
~xfJhC{>mWzcZQ\\_\000ӷS\tcr/*Hx[Ol~ϫ֒k(T.Fr8'O
g
~NM\"e`>Տ;^_V.v*}\"gSNdڷޛ쨯\000(\000(\000;j\000@H__5xB?9e:|(\000o\"?}ǟkZp,kY%낃U~I7T[8B8Qխ\\v
f~O\000/3|OKo*Y8^wxÓ^*^/|-l/\$[KTY31SV
+70b_YC3J+[\000#Pk},ž^2܎hޏ
^zqS^g|R4
꣐1RZh%vc^R6eNJM[6Ͳ(oJGO1\".o}9\\#5#Xӝ۷@'ۿO;po=Ïϵz-]5\\ГWgutb.`[P3tRtH)I^쿮=wEBy{Vv\"NxT&WGV0OI>st,eR+Ht<9ú7>:0OWPE\000PE\000PE\000P\000~Pi\000gLNNi#E8}O5_\000/v<z.&ʳ \000}(OyWhWQ5E.ga!SG?s\tb~ʺ\000>OLG-MjTμ.ZƜL7+Wҡԇ%H(iEϣ٭QS+I[luё?gwsg6tҾVNQIX/,n.)Tdm|GcڒӜ3|CJ襓-V*vՕ|ןJ7/ctp4cK\000\t8k*)<p0/~q-i:H\\Hv\000t\0002?iۧR'yWhZ=䣰@ڼL/^^Rv}[վqz#d߇_KDuMNlGE^ԒO\"U?C_Khey}<4ZWޭl+eӧ80<Zs01@\000Q@\000Q@\000בQw6*qv2\000&\000
Υjt&T!*
)\\V.8PmMumZǩkv)p{-7?w8MVab\000YiQN^HxBM;P}^̥fIyATWd&?Oo\\IkC'6^#^F:Yn:QjwvmIy';ymGV>O4{'|l\000*?|Wet;4Y[y\tFZwsS/c\0006z׀aT_\\q:rP]\000XO[%\000<vo!KN<G\"
0X\000ଗ+.EZ/կZ62\000_cU;g\000aʉ>Z\000 UM@Oj'5qT9}a9uGKR[k7V?F'
65QT\000,cZh_(9;
kx򴹎?9?z\000_
Y<_F7.`n?iKc+\t~
ME\\A\"lqe}{9>hPxwD+{x#[A\000PTS=We~7ZӴn3=̿4ֲDB
~f5*Jp3
(\000
(\000
(\000
)D??*Cg.@ȇg>qLܤ<?U{8v
D%Q\0004gy/KðF: ؽqO=.F,@\\c=\000(\000(\000(\000(\000(\000(\000(\000(\000(\000(\000(\000\tjC&h\000(\000(\000(\000(\000(\000(\000(\000(\000B(GQAAE\000PE\000PE\000PE\000PE\000PE\000PE\000PE\000P\000\000\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/paprika/assets/paprikas.jpg";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/paprika/assets/paprikas.jpg", "/var/www/html/mauticGIT-Test/themes/paprika/assets/paprikas.jpg");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/89/8920e8a5b295408314ea036a9ec3b5de.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/paprika/assets/paprikas.jpg */
class __TwigTemplate_5049f6692acbe41a514e823d702136eb extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "\000JFIF\000\000`\000`\000\000\000hExif\000\000MM\000*\000\000\000\000\000\000\000\000\000\000\000>\000\000\000\000\000\000\000F(\000\000\000\000\000\000\0001\000\000\000\000\000\000\000N\000\000\000\000\000\000\000`\000\000\000\000\000\000`\000\000\000paint.net 4.2.15\000\000\000C\000\t\t\t





\t


\000C


















































\000\000!\000\000\000\000\000\000\000\000\000\000\000\000\t
\000\000\000\000}\000!1AQa\"q2#BR\$3br\t
%&'()*456789:CDEFGHIJSTUVWXYZcdefghijstuvwxyz\000\000\000\000\000\000\000\000\t
\000\000\000w\000!1AQaq\"2B\t#3Rbr
\$4%&'()*56789:CDEFGHIJSTUVWXYZcdefghijstuvwxyz\000\000\000?\000\000K\th
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(N=(\${J

(\000
(\000
(\000}(\000(\000(\000(\000(\000ct}}('w\000q@q@~x\000PG>\000Qրh(\000(J(\000Ҋ\000(\000(\000(\000(\000\t\000h7Nirs@AIށzR,zP!I4dB.dP=}h\000't0@\\\\rh~P0
(\000
(\000
(\0009\0009t@\000sF}(\000&}(9G^G~ZC
( hBt(?\000\000aizC_fq֨K@P]_\\46ֵ(ma_\$dxc]Wku2yqgxx\$9,\"1StRHE[:+9\000(\000ӹ E\000Q(Px\t9&@}M!(8'Es֨H\tj2I(.JP^KA~վ6.5Ե戲+{{}:U+I36dy_-i|-Y\\ڽ-\"SQu'&#\000G8w5վ\0006p\t8_<Lqy]Ƣ6.І;-pت9=fշI_~>@Bik>0(\000N(\000zQ@8\000 }(g>MAl@Sҏt'\0007Nր
P4x_kj=񦟥wrO5ˌapyVMF+V۰64\000~Ǘ|d˶ՔY?cmGxG^l`*N0!*8r˿ȊuֿviQ_LhyoWG迳%ImnLzMO0_s|GOxĨ&W\$fU%a\\vA+\t{4俿R7\000uRlBZ&%vn|ϻ~~>dVdl\\Q^_#-_YIR~m\000xDUIu
+p
(\000u\000&qր\"sPH7E'\000pґ4\000qPFy4MPEO\000x&34QeF\"s^g
/4Km'!U;-v[л\000? kx(b^}!dktv98XsM8|Dm\000ֻ>|,t{+{}?q~3,\000=ku\000○9u7㾛ٞXno(Vv\000?;@Oq[Fۦg'o?
lV)M\000u{g|1֩D\\Ix`ګm3\000\\|fu^(<k-ŕh%\$zG|vy9laq7.DݥlB2ю1{=\000~_ҼQ%oqxOCGqڱ+Qb\\C`yEskͰ8<yYZ`7Թ#)ҩVvݒoƟzW_SyesGğzc)q\000x_/q[<峸b<\"o*縕?iU܂\000TcStR*mtJͯ+h(\000(\000(oI5F8-i*Ơd'\000^\000J\000b{]xfmŬG\$1JARF]~5y<?[ڲi>U{Fq1<&j
Nɾ\000þGo\000oEu0ʪk\000V?íA7F閩&pat8֞#Y^OѦXƾ
後\000zk{zXjÚ~?Ӧ_Zcdw:*\000y
־+|0M6DXcsDڹqX&ɔ[<\000ğbjy\$_ek!1\tXe)Du
Jn6nrO_^,^_q\000q9/+53\\jp\"\000\\K_\000
Qն0M&\000Q\\\000평\000t_4I,33e2??̼Cn'RWKR^Wu3Ek5~ՏWD~
~#_Ǘ(dVЃ|r3}@~֟ƕIon-cgE#s+3 @q.sng{\000js[sstyo3\000@yh^31-V5CjTg>b?qcQ]P\$gyvq1n}ktAFniu;';v
X[^\000%럛eۃ\000bNH|Ac\$M갷@z
cl+
NӺMk\\ҵ\000?੟>
|\000hWr[ƭxSJ(ptӄ\000I]Ao3HY[)8fPJ#FM¿83NmC'RPN{쭦׿>3.>Y7WKo{uvm\000'_[|:wt uFm
Dnk{xm-㵶R8,hT~}.+3jμc.Oj=ܴދzp
(\000p>
i3X7uKn6vHN=kGuO
uVlI,Y8\$6A_~;`qZ꒼b)Kރ5+S*onFeh^(|te3Fs?ˊǾof]W!Z<&CͰs[VKc=Jrw}n{_w=SU߉~]2ׁuh\000BzgxPǠrzO},^*feĒhwvRRm?O+<;ݥNV[\0004ϥAJ*3,[R\000-('[fKonH<;615[G\000xsB/|Kflح1V8c=sἇ;>J޷ۭΟ<tZ\\Vڔ:߫%য়y,> |?-Y<ż3p6}8<+(Mÿ՝ջI|Gy-!9We(ӕH)OYNsuȿbZJ4ͷg}5]\000;??;i#0?G
a6
'o*O߃z<9\\h0K7)zX^\\q):F6\000ZkPsHub.co._M8,^MKݎ0:W>6-xUQMNI%9Ij:~35s;(DWO\\}IEii
f=1
O-[_/o)
z߽{X\\KxZTsڦuxv͑sB1o=Wᰴi[^]Hr|޻~(G\"8VL|בXgR%͢kJ/<_yEִ ocŇ̎M@}{ֿcw\000u[\000[KD\$u/\$wl\000fh䵳ojӕ(.^I\\IQF_6O>'[\000\000
ªoL\0009A6KaաN*+Vmr4yPE\000P0{K4\000P\t?z?{7y?s,v> V}U+c|rco;<[Éx~_-IũAs%~먧Nzr?I^hT\000c5
|Nmգ+~J:\000u
nu&{nNb2Dx8N
E_ѭOQYӒ?=S\000<4=ڹu(\\K|]{tN5b^ \$eZ컸!h2WB
rEu[\0003n5Y5.#v<VrxHҌm)N=/][.6mlu{iwgѹ(.̦ƔkrI\$zu)ɢOp!1Ȳ;VuWo*X<\000/JzB^ZkEvb{mU
τYй\000tq|9669dnvl
~xfJhC{>mWzcZQ\\_\000ӷS\tcr/*Hx[Ol~ϫ֒k(T.Fr8'O
g
~NM\"e`>Տ;^_V.v*}\"gSNdڷޛ쨯\000(\000(\000;j\000@H__5xB?9e:|(\000o\"?}ǟkZp,kY%낃U~I7T[8B8Qխ\\v
f~O\000/3|OKo*Y8^wxÓ^*^/|-l/\$[KTY31SV
+70b_YC3J+[\000#Pk},ž^2܎hޏ
^zqS^g|R4
꣐1RZh%vc^R6eNJM[6Ͳ(oJGO1\".o}9\\#5#Xӝ۷@'ۿO;po=Ïϵz-]5\\ГWgutb.`[P3tRtH)I^쿮=wEBy{Vv\"NxT&WGV0OI>st,eR+Ht<9ú7>:0OWPE\000PE\000PE\000P\000~Pi\000gLNNi#E8}O5_\000/v<z.&ʳ \000}(OyWhWQ5E.ga!SG?s\tb~ʺ\000>OLG-MjTμ.ZƜL7+Wҡԇ%H(iEϣ٭QS+I[luё?gwsg6tҾVNQIX/,n.)Tdm|GcڒӜ3|CJ襓-V*vՕ|ןJ7/ctp4cK\000\t8k*)<p0/~q-i:H\\Hv\000t\0002?iۧR'yWhZ=䣰@ڼL/^^Rv}[վqz#d߇_KDuMNlGE^ԒO\"U?C_Khey}<4ZWޭl+eӧ80<Zs01@\000Q@\000Q@\000בQw6*qv2\000&\000
Υjt&T!*
)\\V.8PmMumZǩkv)p{-7?w8MVab\000YiQN^HxBM;P}^̥fIyATWd&?Oo\\IkC'6^#^F:Yn:QjwvmIy';ymGV>O4{'|l\000*?|Wet;4Y[y\tFZwsS/c\0006z׀aT_\\q:rP]\000XO[%\000<vo!KN<G\"
0X\000ଗ+.EZ/կZ62\000_cU;g\000aʉ>Z\000 UM@Oj'5qT9}a9uGKR[k7V?F'
65QT\000,cZh_(9;
kx򴹎?9?z\000_
Y<_F7.`n?iKc+\t~
ME\\A\"lqe}{9>hPxwD+{x#[A\000PTS=We~7ZӴn3=̿4ֲDB
~f5*Jp3
(\000
(\000
(\000
)D??*Cg.@ȇg>qLܤ<?U{8v
D%Q\0004gy/KðF: ؽqO=.F,@\\c=\000(\000(\000(\000(\000(\000(\000(\000(\000(\000(\000(\000\tjC&h\000(\000(\000(\000(\000(\000(\000(\000(\000B(GQAAE\000PE\000PE\000PE\000PE\000PE\000PE\000PE\000P\000\000\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/paprika/assets/paprikas.jpg";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/paprika/assets/paprikas.jpg", "/var/www/html/production-demo/themes/paprika/assets/paprikas.jpg");
    }
}
